import { useState, FormEvent } from "react";
import { useLocation } from "wouter";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { 
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { LOCATIONS, PRICE_RANGES, ITEM_CONDITIONS } from "@/lib/constants";

interface SearchBarProps {
  compact?: boolean;
}

const SearchBar = ({ compact = false }: SearchBarProps) => {
  const [, navigate] = useLocation();
  const [searchTerm, setSearchTerm] = useState("");
  const [location, setLocation] = useState("Toute la Guadeloupe");
  const [category, setCategory] = useState("all");
  const [priceRange, setPriceRange] = useState("all");
  const [condition, setCondition] = useState("all");
  const [sellerType, setSellerType] = useState("all");
  const [urgency, setUrgency] = useState("all");
  const [publicationDate, setPublicationDate] = useState("all");
  const [showMoreFilters, setShowMoreFilters] = useState(false);
  
  const handleSearch = (e: FormEvent) => {
    e.preventDefault();
    
    const params = new URLSearchParams();
    if (searchTerm) params.append("q", searchTerm);
    if (location !== "Toute la Guadeloupe") params.append("location", location);
    if (category) params.append("category", category);
    if (priceRange) {
      const [min, max] = priceRange.split("-");
      if (min) params.append("minPrice", min);
      if (max) params.append("maxPrice", max);
    }
    if (condition) params.append("condition", condition);
    
    navigate(`/search?${params.toString()}`);
  };
  
  return (
    <div className="bg-teal-50 py-6 shadow-sm">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="bg-white rounded-lg p-4 border border-teal-200 shadow-md">
          <form onSubmit={handleSearch}>
            <div className="grid grid-cols-1 md:grid-cols-4 gap-4">
              <div className={compact ? "col-span-1 md:col-span-2" : "col-span-2"}>
                <div className="relative">
                  <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                    <i className="fas fa-search text-teal-500"></i>
                  </div>
                  <Input
                    type="text"
                    className="pl-10 pr-3 py-3 border-teal-300 focus:border-teal-500 focus:ring-teal-500"
                    placeholder="Que recherchez-vous?"
                    value={searchTerm}
                    onChange={(e) => setSearchTerm(e.target.value)}
                  />
                </div>
              </div>
              
              <div className="col-span-1">
                <Select value={location} onValueChange={setLocation}>
                  <SelectTrigger className="pl-10 border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <i className="fas fa-map-marker-alt text-teal-500"></i>
                    </div>
                    <SelectValue placeholder="Toute la Guadeloupe" />
                  </SelectTrigger>
                  <SelectContent>
                    {LOCATIONS.map((loc) => (
                      <SelectItem key={loc} value={loc}>{loc}</SelectItem>
                    ))}
                  </SelectContent>
                </Select>
              </div>
              
              <div className="col-span-1">
                <Button className="w-full bg-teal-600 hover:bg-teal-700 text-white font-bold" type="submit">
                  <i className="fas fa-search mr-2"></i>
                  Rechercher
                </Button>
              </div>
            </div>
            
            {!compact && (
              <div className="mt-4 flex flex-wrap gap-2 items-center">
                <span className="text-sm font-medium text-teal-800">Filtres:</span>
                
                <Select value={category} onValueChange={setCategory}>
                  <SelectTrigger className="h-8 text-sm border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                    <SelectValue placeholder="Catégories" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="all">Toutes les catégories</SelectItem>
                    <SelectItem value="vehicules">Véhicules</SelectItem>
                    <SelectItem value="immobilier">Immobilier</SelectItem>
                    <SelectItem value="meubles">Meubles</SelectItem>
                    <SelectItem value="multimedia">Multimédia</SelectItem>
                  </SelectContent>
                </Select>
                
                <Select value={priceRange} onValueChange={setPriceRange}>
                  <SelectTrigger className="h-8 text-sm border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                    <SelectValue placeholder="Prix" />
                  </SelectTrigger>
                  <SelectContent>
                    {PRICE_RANGES.map((range) => (
                      <SelectItem key={range.value} value={range.value}>{range.label}</SelectItem>
                    ))}
                  </SelectContent>
                </Select>
                
                <Select value={condition} onValueChange={setCondition}>
                  <SelectTrigger className="h-8 text-sm border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                    <SelectValue placeholder="État" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="all">Tous les états</SelectItem>
                    {ITEM_CONDITIONS.map((cond) => (
                      <SelectItem key={cond.value} value={cond.value}>{cond.label}</SelectItem>
                    ))}
                  </SelectContent>
                </Select>
                
                <Button 
                  type="button"
                  variant="outline" 
                  className="h-8 text-sm border-teal-300 text-teal-700 hover:bg-teal-50 hover:text-teal-800"
                  onClick={() => setShowMoreFilters(!showMoreFilters)}
                >
                  Plus de filtres <i className={`fas fa-angle-${showMoreFilters ? 'up' : 'down'} ml-1`}></i>
                </Button>
              </div>
            )}
            
            {!compact && showMoreFilters && (
              <div className="mt-4 grid grid-cols-1 md:grid-cols-3 gap-4 bg-teal-50 p-4 rounded-md">
                {/* Additional filters would go here */}
                <div className="col-span-1">
                  <label className="block text-sm font-medium text-teal-800 mb-1">Type de vendeur</label>
                  <Select value={sellerType} onValueChange={setSellerType}>
                    <SelectTrigger className="text-sm border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                      <SelectValue placeholder="Tous les vendeurs" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">Tous les vendeurs</SelectItem>
                      <SelectItem value="professional">Professionnel</SelectItem>
                      <SelectItem value="individual">Particulier</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
                
                <div className="col-span-1">
                  <label className="block text-sm font-medium text-teal-800 mb-1">Urgence</label>
                  <Select value={urgency} onValueChange={setUrgency}>
                    <SelectTrigger className="text-sm border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                      <SelectValue placeholder="Toutes les annonces" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">Toutes les annonces</SelectItem>
                      <SelectItem value="urgent">Urgentes uniquement</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
                
                <div className="col-span-1">
                  <label className="block text-sm font-medium text-teal-800 mb-1">Date de publication</label>
                  <Select value={publicationDate} onValueChange={setPublicationDate}>
                    <SelectTrigger className="text-sm border-teal-300 focus:border-teal-500 focus:ring-teal-500">
                      <SelectValue placeholder="Toutes les dates" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">Toutes les dates</SelectItem>
                      <SelectItem value="today">Aujourd'hui</SelectItem>
                      <SelectItem value="week">Cette semaine</SelectItem>
                      <SelectItem value="month">Ce mois-ci</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
              </div>
            )}
          </form>
        </div>
      </div>
    </div>
  );
};

export default SearchBar;
